class KctTrailsController < ApplicationController
  before_action :set_trail, only: [:show, :edit, :update, :destroy]
  before_action :ensure_admin!
  
  # GET /kct_trails
  # GET /kct_trails.json
  def index
    @kct_trails = KctTrail.all
    # filter
    if params[:search]
      @kct_trails = @kct_trails.where("kctref LIKE '%#{params[:search]}%'")
    end
    
    # sort
    @kct_trails = if params[:sort] == 'priority'
      @kct_trails.reorder('priority IS NULL, priority, kctref')
    else
      @kct_trails.order(:kctref)
    end
    
    # paginate
    @kct_trails = @kct_trails.page(params[:page])
  end

  # GET /kct_trails/1
  # GET /kct_trails/1.json
  def show
  end

  # GET /kct_trails/new
  def new
    @kct_trail = KctTrail.new
  end

  # GET /kct_trails/1/edit
  def edit
  end

  # POST /kct_trails
  # POST /kct_trails.json
  def create
    @kct_trail = KctTrail.new(trail_params)

    respond_to do |format|
      if @kct_trail.save
        format.html { redirect_to @kct_trail, notice: 'KctTrail was successfully created.' }
        format.json { render action: 'show', status: :created, location: @kct_trail }
      else
        format.html { render action: 'new' }
        format.json { render json: @kct_trail.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /kct_trails/1
  # PATCH/PUT /kct_trails/1.json
  def update
    respond_to do |format|
#       raise params[:trail].inspect
      if @kct_trail.update_attributes(trail_params)
        format.html { redirect_to @kct_trail, notice: 'KctTrail was successfully updated.' }
        format.json { head :no_content }
      else
        format.html { render action: 'edit' }
        format.json { render json: @kct_trail.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /kct_trails/1
  # DELETE /kct_trails/1.json
  def destroy
    @kct_trail.destroy
    respond_to do |format|
      format.html { redirect_to trails_url }
      format.json { head :no_content }
    end
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_trail
      begin
        if params[:id].match /kctref-(.*)/  # umožňuje použíte kctref-XXXX místo id v databázi
          @kct_trail = KctTrail.find_by_kctref($1)
        else
          @kct_trail = KctTrail.find(params[:id])
        end
      rescue ActiveRecord::RecordNotFound
        flash.alert = "Tento kct trail není v databázi. Možná jde o starý odkaz a mezitím byla databáze reimportována."
        redirect_to :action=> :index
      end
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def trail_params
      params.require(:kct_trail).permit(:kctref, :osmid, :nazev, :nazev_normalized, :barva, :typ, :error)
    end
end
